/*
	First part of Poisson chapter, up to and including section 4.4
*/
version 11.0
set more off
clear
use rott2

/* Equivalence of streg and glm */
streg recent, dist(exp) nolog nohr noshow
glm _d recent, family(poisson) lnoffset(_t) nolog

/* list example of unsplit data */
list pid _t0 _t _d if inlist(pid,2553,784,1167), noobs

/* list example of split data */
stsplit split_time, every(1)
gen risktime = _t - _t0
list pid _t0 _t _d split_time risktime if inlist(pid,2553,784,1167), ///
	sepby(pid) ab(10) noobs

/* Piecewise exponential model */
glm _d ibn.split_time recent, family(poisson) lnoffset(risktime) ///
	nocons nolog eform noheader

/* streg on split data */
streg ibn.split_time recent, dist(exp) nolog noshow nocons noheader

// Figure 4.2
/* graph of predictions using csurv */
predict surv, csurv
twoway (line surv _t if recent == 0, sort) ///
	(line surv _t if recent == 1, sort) ///
	, scheme(sj) ///
	legend(order(1 "1978-1987" 2 "1988-1993") ring(0) pos(5) cols(1)) ///
	yscale(range(0 1)) ylabel(0(0.2)1, angle(horizontal) format(%3.1f)) ///
	ytitle("S(t)") xtitle("Time from surgery (years)")

/* collapse data */
collapse (min) start=_t0 (max) end = _t (count) n=_d (sum) risktime _d, ///
	by(split_time recent)
sort recent split_time
list recent start end n risktime _d, sepby(recent) noobs

/* Fit glm to collapsed data */
glm _d ibn.split_time recent, family(poisson) lnoffset(risktime) ///
	nocons nolog eform noheader
set more on
