/*
	Chapter 4
	Using fraction polynomials with Poisson models
	Includes figures 4.13, 4.14, 4.15
*/
version 11.0
set more off
clear

/* Load data and split follow-up time */
use rott2
stsplit split_time, every(`=1/12')
gen risktime = _t - _t0
collapse (min) start=_t0 (max) end = _t (count) n=_d (sum) risktime _d, ///
    by(split_time recent)
gen midt = (start + end)/2

/* FP3 model for baseline hazard */
fracpoly, degree(3) compare: glm _d midt recent, ///
	family(poisson) lnoffset(risktime) noheader 

predict lh_fp3, nooffset xb
predict lh_fp3_se, nooffset stdp
gen h_fp3 = exp(lh_fp3)*1000
gen h_fp3_lci = exp(lh_fp3 - 1.96*lh_fp3_se)*1000
gen h_fp3_uci = exp(lh_fp3 + 1.96*lh_fp3_se)*1000

/* Best fitting FP2 and FP1 models */
fracpoly: glm _d midt -0.5 0 recent, ///
	family(poisson) lnoffset(risktime) noheader
predict lh_fp2, nooffset xb
gen h_fp2 = exp(lh_fp2)*1000
fracpoly: glm _d midt 2 recent, ///
	family(poisson) lnoffset(risktime) noheader
predict lh_fp1, nooffset xb
gen h_fp1 = exp(lh_fp1)*1000

// Figure 4.13
/* graph comparing FP1 FP2 and FP3 model */
twoway 	(line h_fp1 midt if recent == 0, lpattern(solid) lwidth(medthick)) ///
		(line h_fp2 midt if recent == 0, lpattern(longdash) lwidth(medthick)) ///
		(line h_fp3 midt if recent == 0, lpattern(dash) lwidth(medthick)) ///
		, scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(0(50)200,angle(h) format(%3.0f)) ///
		legend(order(1 "FP1" 2 "FP2" 3 "FP3") ring(0) pos(1) cols(1))  

// Figure 4.14
/* graph of best fitting FP3 model */
twoway 	(rarea h_fp3_lci h_fp3_uci midt if recent == 0, sort pstyle(ci)) ///
		(line h_fp3 midt if recent == 0, sort lpattern(solid)) ///
		, scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(0(50)200,angle(horizontal) format(%3.0f)) ///
		legend(off)

// Figure 4.15
/* graph comparing FP3 and FP4 models */
fracpoly, degree(4): glm _d midt recent, ///
	family(poisson) lnoffset(risktime) noheader 
estimates store fp4
predict lh4, nooffset xb
predict lh4_se, nooffset stdp
gen h_fp4 = exp(lh4)*1000
gen h_fp4_lci = exp(lh4 - 1.96*lh4_se)*1000
gen h_fp4_uci = exp(lh4 + 1.96*lh4_se)*1000
twoway 	(line h_fp3 midt if recent == 0, sort) ///
		(line h_fp4 midt if recent == 0, sort) ///
		, scheme(sj) ///
		xtitle("Years from surgery") ///
		ytitle("Recurrence rate (per 1000 PYs)") ///
		ylabel(0(50)200,angle(horizontal) format(%3.0f)) ///
		legend(order(1 "FP3" 2 "FP4") ring(0) col(1) pos(1))		
set more on	
