/*
	Figure 5.4
	Difference in hazard and survival functions, not assuming PH.
	Note: due perhaps to a bug in Stata, I could only save this graph
	via loading it into the graph editor and saving it afresh.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Approach 2: stpm2 with 2 knots
stpm2, df(3) scale(hazard) nolog
predict hstpm, hazard ci

// Approach 3: FP3 functions
sts gen Hna = na
gen lnHna = ln(Hna)
fracpoly regress lnHna _t, degree(3)
predict lnHtilde
fracdydx, gen(hazard)
replace hazard = hazard * exp(lnHtilde)

/*
	Save data.
	Plot smoothed hazard and save graph.
	Discard, then use serset 0 to retrieve plotted values.
	First variable is smoothed hazard, looks like __000000 or
	something similar. Second is _t.
*/
save temp, replace
sts graph, hazard kernel(epan2) ///
 xtitle("Years from surgery") ytitle("Hazard rate") ///
 ysca(r(0 .16)) yla(0(.04).16, angle(h) format(%4.2f)) xsca(r(0 10)) xla(0(2)10) ///
 sav(temp, replace)
discard
graph use temp
serset 0
serset use, clear
unab h: __* // get name of smoothed-hazard variable
rename `h' hsts
rename _t t2
save temp2, replace

use temp, replace
append using temp2

foreach v of var hstpm_lci hstpm_uci hsts hstpm hazard {
	replace `v' = `v' * 100
}

graph twoway (rarea hstpm_lci hstpm_uci _t, pstyle(ci) sort) ///
 (line hsts t2, sort lpattern(-) lwidth(medthick)) ///
 (line hstpm hazard _t, sort lpattern(l _) lwidth(medthick ..) legend(off)) ///
 , xtitle("Years from surgery") ytitle("Recurrence rate per 100 woman years") ///
 yscale(r(0 17)) ylabel(0(4)16, angle(h)) xscale(r(0 10)) xlabel(0(2)10)

erase temp.dta
erase temp2.dta
set more on
