/*
	Figure 5.1
	Rotterdam data. Compare cumulative hazard function for the
	exponential model with Nelson-Aalen, also survival function
	with Kaplan-Meier.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Generate non-parametric estimates
sts gen Hna = na
sts gen Hlb = lb(na)
sts gen Hub = ub(na)
sts gen S = s
sts gen Slb = lb(s)
sts gen Sub = ub(s)

// Fit -streg- exponential model
quietly streg, distribution(exponential)
predict Sexp, surv
gen Hexp = -ln(Sexp)

// Plot results
quietly bysort _t: drop if _n > 1
twoway (rarea Hlb Hub _t, pstyle(ci) sort) ///
 (line Hna Hexp _t, sort lstyle(refline ..) pstyle(p2 ..)) ///
 , leg(off) ytitle("Cumulative hazard function") xtitle("") ///
 ylab(, angle(h) format(%4.1f)) name(g1, replace) nodraw
twoway (rarea Slb Sub _t, pstyle(ci) sort) ///
 (line S Sexp _t, sort lstyle(refline ..) pstyle(p2 ..)) ///
 , leg(off) ytitle("Survival function") xtitle("") ///
 ylab(, angle(h) format(%4.1f)) name(g2, replace) nodraw
graph combine g1 g2, b2title("Years from surgery")

set more on
