/*
	Figure 5.2
	Rotterdam data. Compare cumulative hazard function for the
	Weibull model with Nelson-Aalen, also survival function with
	Kaplan-Meier.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

sts gen Hna = na
sts gen Hlb = lb(na)
sts gen Hub = ub(na)
sts gen S = s
sts gen Slb = lb(s)
sts gen Sub = ub(s)

streg, distribution(weibull)
gen Hexp = exp(_b[_cons]) * _t^exp([ln_p]_b[_cons])
gen Sexp = exp(-Hexp)

preserve
qui bysort _t: drop if _n>1

twoway (rarea Hlb Hub _t, pstyle(ci) sort) ///
 (line Hna Hexp _t, sort lstyle(refline ..) pstyle(p2 ..)) ///
 , leg(off) ytitle("Cumulative hazard function") xtitle("") ///
 ylab(, angle(h) format(%4.1f)) name(g1, replace) nodraw

twoway (rarea Slb Sub _t, pstyle(ci) sort) ///
 (line S Sexp _t, sort lstyle(refline ..) pstyle(p2 ..)) ///
 , leg(off) ytitle("Survival function") xtitle("") ///
 ylab(, angle(h) format(%4.1f)) name(g2, replace) nodraw

graph combine g1 g2, b2title("Years from surgery")
restore
set more on
