/*
	Chapter 6
	Fit PH model for nodes. Predict baseline survival with and
	without centering of nodes. Plot together with Kaplan-Meier.
	Figure 6.1
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Center enodes on mean
sum enodes
gen enodes_cent = enodes - r(mean)

// Fit uncentered covariate
quietly stpm2 enodes, df(2) scale(hazard)
predict s0, survival zeros

// Fit centered covariate
quietly stpm2 enodes_cent, df(2) scale(hazard)
predict s1, survival zeros

// Kaplan-Meier
sts gen s = s
line s0 s1 s _t, sort xtitle("Years from surgery") ///
 ytitle("S(t)") connect(l l J) ylabel(, angle(h) format(%4.1f)) ///
 legend(label(1 "enodes (uncentered)") label(2 "enodes (centered)") ///
 label(3 "Kaplan-Meier") ring(0) pos(1) col(1))
set more on
