/*
	Chapter 6
	Figure 6.14
	Impute censored survival times and plot smooth ln(t) against nodes.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model and predict prognostic index
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
predict xb, xbnobaseline

// Impute censored times under PCO(2) model
stsurvimpute xb, seed(111) gen(timp) scale(odds) df(2)

// Refit model to xb and estimate survival probabilities
quietly stpm2 xb, scale(odds) df(2)
local obs +
local imp o
label define d 0 "`imp'" 1 "`obs'"
label values _d d

// Get cutpoints on predicted survival time for plotting
centile xb, centile(10 25 75 90)
forvalues j = 1 / 4 {
	local cut`j' = r(c_`j')
}
gen lnt = ln(timp)
global stuff xtitle("") ytitle("") xlabel(0(10)30) xscale(r(0 35)) title("") ///
 lineopts(lstyle(refline)) scatter(msymbol(oh) msize(medsmall))
running lnt nodes, $stuff name(g1, replace) ci yla(, angle(h))
running lnt nodes, $stuff name(g2, replace) nopts ///
 ci ylabel(, angle(horizontal) format(%4.1f))
 graph combine g1 g2, l1title("Log years since surgery") b2title("nodes")
set more on
