/*
	Chapter 6
	Figure 6.6
	Survival functions in prognostic groups.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit fractional polynomial model and predict prognostic index
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
predict xb, xbnobaseline

// Form 5 prognostic groups using cut-points at 10, 25, 75 and 90 centiles
centile xb, centile(10 25 75 90)
gen cutpoints = .
forvalues j = 1 / 4 {
	quietly replace cutpoints = r(c_`j') in `j'
}

// Create grouping variable, xbc5, with 5 levels
xtile xbc5 = xb, cutpoints(cutpoints)

// Compute mean survival and Kaplan-Meier curves in each group
forvalues j = 1 / 5 {
	predict s`j' if xbc5 == `j', meansurv
	sts gen km`j' = s if xbc5 == `j'
}

// Plot
line s1 s2 s3 s4 s5 km1 km2 km3 km4 km5 _t, ///
 sort connect(l l l l l J J J J J) lpattern(- - - - - l l l l l) ///
 xtitle("Years since surgery") ytitle("S(t)") yscale(r(0 1))  ///
 ylabel(0(0.2)1, angle(h) format(%4.1f)) legend(off) ///
 text(.82 10 "{&le} 10th centile", place(w)) ///
 text(.62 10 "10-25th centile", place(w)) ///
 text(.45 10 "25-75th centile", place(w)) ///
 text(.31 10 "75-90th centile", place(w)) ///
 text(.16 10 "> 90th centile", place(w))
set more on
