/*
	Chapter 6
	Figures 6.2, 6.3
	Histograms of predicted survival probabilities at 2 and 5 years,
	and conditional survival at 5 years given 2 years, for MFP model.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

// Fit MFP model and predict prognostic index
quietly xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon, ///
 scale(odds) df(2)
gen t2 = 2
gen t5 = 5
predict s2, timevar(t2) survival
predict s5, timevar(t5) survival
global stuff ytitle("") ylabel(, angle(horizontal)) ///
 xtitle("") xlabel(, format(%4.1f)) 
histogram s2, $stuff name(g1, replace) title("t = 2 years")
histogram s5, $stuff name(g2, replace) title("t = 5 years")

// Figure 6.2
graph combine g1 g2, xcommon ycommon name(g1_g2) ///
 b2title("Survival probability") l1title("Density")

// Conditional survival 5 yr given 2 yr
gen s52 = s5 / s2
// Figure 6.3
histogram s52, xtitle("Survival probability") xla(0(.2)1, angle(h) format(%4.1f)) xsca(r(0 1)) ///
 ytitle("Density") title("Conditional survival, 5 yr | 2 yr") yla(, angle(h))

set more on
