/*
	Chapter 6
	Table 6.1
	Explore preliminary full model to get idea of which scale is best.
*/
version 11.0
set more off
clear
use rott2

// Categorise continuous predictors in 5 groups
foreach v of var age nodes pr er year {
	xtile `v'c5 = `v', n(5)
}

foreach scale in hazard odds normal theta {
	di _n "Scale = `scale'"
	forvalues j = 1/5 {
		qui xi: stpm2 i.agec5 i.nodesc5 i.prc5 i.erc5 i.yearc5 i.size i.grade ///
		 meno chemo hormon , df(`j') scale(`scale')
		di "df = `j', AIC = " %7.2f e(AIC) " BIC = " %7.2f e(BIC)
	}
}

// Same, assuming linearity
foreach scale in hazard odds normal theta {
	di _n "Scale = `scale'"
	forvalues j = 1/5 {
		qui xi: stpm2 age nodes pr er year i.size i.grade ///
		 meno chemo hormon , df(`j') scale(`scale')
		di "df = `j', AIC = " %7.2f e(AIC) " BIC = " %7.2f e(BIC)
	}
}

// Same, without covariates. Exclude theta, does not converge for df > 1.
foreach scale in hazard odds normal {
	di _n "Scale = `scale'"
	forvalues j = 1/5 {
		qui xi: stpm2, df(`j') scale(`scale')
		di "df = `j', AIC = " %7.2f e(AIC) " BIC = " %7.2f e(BIC)
	}
}
set more on
