/*
	Chapter 7: piecewise stpm2 models.
	Includes figure 7.10 and figure 7.11
*/
version 11.0
set more off
clear
use ew_breast_ch7

stset survtime, failure(dead==1) exit(time 5) id(ident)
stpm2 dep5, scale(hazard) df(5) eform nolog

stsplit split_time, at(1 2)		
qui tab split_time, gen(int)
forvalues i = 1/3 {
	gen dep5int`i' = dep5*int`i'
}						
stpm2 dep5int1-dep5int3, scale(hazard) df(5) eform nolog
range temptime 0 5 200
predict h_stpm2, hazard zeros timevar(temptime) 
estimates store stpm2

predict h, hazard

qui stcox dep5int1-dep5int3
estimates store cox
range timevar1 0 1 200
range timevar2 1 2 200
range timevar3 2 5 200
forvalues i = 1/3 {
	qui stpm2 dep5int`i' if int`i' == 1, df(5) scale(hazard)  
	estimates store stpm2_int`i'
	predict h_int`i' if int`i' == 1, hazard zeros timevar(timevar`i') 
}
estimates table cox stpm2 stpm2_int1 stpm2_int2 stpm2_int3, ///
	equations(1) eform se(%6.4f) b(%6.4f) modelwidth(10) ///
	drop(dxb: xb0: _rcs1 _rcs2 _rcs3 _rcs4 _rcs5 _cons) 

// Figure 7.10
twoway (line h_stpm2 temptime, sort lcolor(black) lwidth(thick)) ///
		(line h_int1 timevar1 if int1 == 1, sort lcolor(gs5) lpattern(dash)) ///
		(line h_int2 timevar2 if int2 == 1, sort lcolor(gs5) lpattern(dash)) ///
		(line h_int3 timevar3 if int3 == 1, sort lcolor(gs5) lpattern(dash)) ///
		, scheme(sj) ///
		legend(order(1 "Baseline hazard from single model" ///
					   2 "Baseline hazard from separate models") ring(0) pos(5) cols(1)) ///
		ylabel(,angle(h) format(%3.2f)) ytitle(Hazard rate) ///
		xtitle("Time from diagnosis (years)")
		
// Figure 7.11
twoway (line h _t if dep5 == 0, sort  lwidth(thick)) ///
		(line h _t if dep5 == 1 & _t<=1, sort  lwidth(thick) lpattern(dash)) ///
		(line h _t if dep5 == 1 & _t>1 & _t<=2, sort  lwidth(thick) lpattern(dash)) ///
		(line h _t if dep5 == 1 & _t>2, sort  lwidth(thick) lpattern(dash)) ///
		, scheme(sj) ///
		legend(order(1 "Least deprived" ///
					   2 "Most deprived") ring(0) pos(5) cols(1)) ///
		ylabel(,angle(h) format(%3.2f)) ytitle(Hazard rate) ///
		xtitle("Time from diagnosis (years)")
set more on
