/*
	Chapter 7. Proportional on which scale? Fits model on the odds
	and theta scales and predicts the hazard ratio.
	Includes figures 7.4, 7.5.
*/
version 11.0
set more off
clear
use ew_breast_ch7

/* Proportional Odds Model */
stset survtime, failure(dead==1) exit(time 5) id(ident)
stpm2 dep5, scale(odds) df(5) eform nolog

/* prediction of time-dependent hazard ratio */
range temptime 0.03 5 200
predict hr_po, hrnumerator(dep5 1) timevar(temptime) ci

// Figure 7.4
twoway		(rarea	hr_po_lci hr_po_uci temptime, sort pstyle(ci)) ///
			(line hr_po temptime, sort lwidth(thick) lcolor(black) lpattern(solid)) ///
			, legend(off) ///
			ytitle("Hazard ratio") ///
			xtitle("Years from diagnosis") ///
			yscale(range(1 3.5)) ylabel(1(0.5)3.5, angle(h)) yscale(log)

/* Theta Model */
stpm2 dep5, scale(theta) df(5) nolog

predict hr_theta, hrnum(dep5 1) timevar(temptime) ci

// Figure 7.5
twoway		(rarea	hr_theta_lci hr_theta_uci temptime, sort pstyle(ci)) ///
			(line hr_theta temptime, sort lwidth(thick) lcolor(black) lpattern(solid)) ///
			, legend(off) ///
			ytitle("Hazard ratio") ///
			xtitle("Years from diagnosis") ///
			yscale(range(1 3.5)) ylabel(1(0.5)3.5, angle(h)) yscale(log)

