/*
	Chapter 9
	Figure 9.10
	CD4 data. Smooths of the first four central moments of z-scores
	from the probit(2) model plotted against x (transformed age).
*/
version 11.0
set scheme sj
set more off
clear
use cd4
stset cd4

quietly stpm2 x_1 x_2, scale(normal) df(2) dftvc(2) tvc(x_1 x_2)

// Compute reference centiles
predict c3, centile(3)
replace c3 = ln(c3)
predict c97, centile(97)
replace c97 = ln(c97)

// Compute Z scores
predict z, normal
gen y1 = 0
gen y2 = 1
gen y4 = 3
gen z2 = z^2
gen z3 = z^3
gen z4 = z^4

// Do running line smooths of first four moments of Z-scores
global stuff nodraw title("") yla(, angle(h) format(%4.1f)) xla(0(1)3) xsca(r(0 3.3))
running z x, clp(l) ci nopts yline(0) addplot(line y1 x,sort clp(l)) name(g1, replace) ///
 xtitle("") ytitle("Z-scores", size(large)) $stuff
running z2 x, clp(l) ci nopts yline(1) addplot(line y2 x,sort clp(l)) name(g2, replace) ///
 xtitle("") ytitle("Z-scores ^ 2", size(large)) $stuff
running z3 x, clp(l) ci nopts yline(0) addplot(line y1 x,sort clp(l)) name(g3, replace) ///
 xtitle("") ytitle("Z-scores ^ 3", size(large)) $stuff
running z4 x, clp(l) ci nopts yline(3) addplot(line y4 x,sort clp(l)) name(g4, replace) ///
 xtitle("") ytitle("Z-scores ^ 4", size(large)) $stuff
graph combine g1 g2 g3 g4, b2title("Transformed age") 
set more on
