/*
	Chapter 9
	Period analysis estimates using E&W breast cancer data
*/
version 11.0
set more off
clear
use ew_breast_ch9

/* stset using dates */
stset dateexit, failure(dead==1) id(ident)  scale(365.24) ///
	origin(datediag) exit(time datediag + 5*365.24)

/* stset exit at start of 1991 */
stset dateexit, failure(dead==1) id(ident)  scale(365.24) ///
	origin(datediag) exit(time mdy(1,1,1991))

/* stset with one year period window */
stset dateexit, failure(dead==1) id(ident)  scale(365.24) ///
	origin(datediag) exit(time mdy(1,1,1991)) ///
	enter(time mdy(1,1,1990))

/* merge in background mortality */
gen age = int(min(agediag + _t,99))
gen year = int(year(datediag) + _t)
merge m:1 sex region dep year age using popmort_uk ///
	,keepusing(rate) keep(match) 

/* Fit model with delayed entry */
stpm2 agegrp2-agegrp5, scale(hazard) df(7) bhazard(rate) nolog ///
	tvc(agegrp2-agegrp5) dftvc(3) 

range temptime 0.003 5 200 
predict s1_period, survival zeros timevar(temptime)
forvalues i = 2/5 {
	predict s`i'_period, survival at(agegrp`i' 1) zeros timevar(temptime)
}
list s1_period-s5_period if temptime == 5, noobs

/* Equivalent esimates from standard analysis */
clear
quietly{
	use ew_breast_ch9, clear
	stset dateexit, failure(dead==1) id(ident)  scale(365.24) ///
	origin(datediag) exit(time mdy(1,1,1991))

	gen age = int(min(agediag + _t,99))
	gen year = int(year(datediag) + _t)
	merge m:1 sex region dep year age using popmort_uk ///
		,keepusing(rate) keep(match) 

	stpm2 agegrp2-agegrp5, scale(hazard) df(7) bhazard(rate) nolog ///
		tvc(agegrp2-agegrp5) dftvc(3) 

	range temptime 0.003 5 200 
	predict s1_standard, survival zeros timevar(temptime)
	forvalues i = 2/5 {
		predict s`i'_standard, survival at(agegrp`i' 1) zeros timevar(temptime)
	}
}
list s1_standard-s5_standard if temptime == 5, noobs
set more on
